// Copyright (C) 2010 - DIGITEO - Michael Baudin
// Copyright (C) 1993 - 1995 - Anders Holtsberg
// Copyright (C) 1998 - 2000 - Mathematique Universite de Paris-Sud - Jean Coursol
// Copyright (C) INRIA
//
// This file must be used under the terms of the CeCILL.
// This source file is licensed as described in the file COPYING, which
// you should have received as part of this distribution.  The terms
// are also available at
// http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt

//STIXDEMO Demonstrate various stixbox routines.
 
disp("When paused with -->halt() enter return key to continue")
disp("When halted without --> mouse click on the plot")

scf();
clf();

disp("Let us start with some data, for example a small correlated")
disp("two dimensional sample with some weird underlying distribution.")
 
n = 20;
Y=grand(n,1,"chi",3);
U=grand(n,1,"unf",0,1);
X = Y+3*U;

halt()

disp("==================== IDENTIFY ====================")
disp("The first thing to do is to plot the data.")
disp("Now, identify the numbers of some interesting observations")
disp("by clicking with the left mouse button on them. Quit by")
disp("clicking with the middle mouse button.")
  
identify(X,Y)
 
halt()

disp("========================================================")
disp("      THE JACKKNIFE AND THE BOOTSTRAP ESTIMATE")
disp("                OF STANDARD DEVIATION")
disp("========================================================")
// 
disp("Let us compute the mean of X and its estimated standard")
disp("deviation.")

disp("mean(X)")
disp(mean(X))
disp("std(X)/sqrt(n)")
disp(std(X)/sqrt(n))
disp("stdjack(X,""mean"")")
disp(stdjack(X,"mean"))
disp("stdboot(X,""mean"")")
disp(stdboot(X,"mean"))
halt()
disp("The same thing for the median.")
 
disp("median(X)")
disp(median(X))
disp("stdjack(X,""median"")")
disp(stdjack(X,"median"))
disp("stdboot(X,""median"")")
disp(stdboot(X,"median"))
halt()
disp("A spectacular example is to give confidence intervals for the")
disp("quantile of a distribution. There are at least 3 ways to define")
disp("an empirical quantile estimator. Look at the plot to see them")
disp("applied to X.")
 
%v = X;
if min(size(%v))==1 then 
  %v=gsort(%v);
else  
 %v=gsort(%v,"r"); 
end;
XX = %v($:-1:1,:);
%v$2 = ((0:n)')/n;
%v$2 = [XX(1);XX];
%v$2 = %v$2';
%v$2 = %v$2';
xmin=floor(min(%v$2));
xmax=ceil(max(%v$2));
clf();
plot2d2('gnn',%v$2,%v$2/xmax,style=3,rect=[xmin,xmin,xmax,1]);
plot2d(XX,(((1:n)')-0.5)/n,style=9)
plot2d(XX,((1:n)')/(n+1),style=5)
ax=gca();ax.grid=[1 1];

halt()
disp("Let us use the method indicated by the green line and compute")
disp("some quantiles for X along with its standard deviation. The")
disp("bootstrap is used for computing a standard deviation estimate")
disp("which we use for plotting a 90 percent confidence interval through")
disp("a normal approximation.")

clf()
p = (0.1:0.1:0.9)';
qx = quantile(X,p,1);
sqx = stdboot(X,"quantile",200,p);
plot2d([p,p,p],[qx-1.6399999999999999*sqx,qx,qx+1.6399999999999999*sqx]);
ax=gca();ax.grid=[1 1];
halt()
disp("However, there are fancier methods than normal approximations ...")
// 
disp("Let us redo the quantile example with full fledged bootstrap")
disp("confidence intervals based on 1000 simulations.")

Imb = ciboot(X,"quantile",[],0.9,2000,p);
clf();
plot2d([p,p,p],Imb);
ax=gca();ax.grid=[1 1];

disp("Great fun, isn''t it?")

disp("A bootstrap confidence interval is based on the bootstrap")
disp("distribution for some quantity. One might have a look at the")
disp("distribution for it. The confidence interval for the standard")
disp("deviation of X will serve as an example.")
 
[Imb,T] = ciboot(X,"std",[],0.9,1000);
Imb = Imb

halt()

disp("A histogram of the bootstrapped distribution of T (=std(X))")
disp("and a kernel density estimate looks like this.")

clf() 
subplot(211)
histo(T);
subplot(212)
plotdens(T);

disp("One might plot the histogram on top of the kernel density")
disp("estimate also.")
halt()
histo(T,[],0,1,1);

halt()

disp("================= LINEAR REGRESSION ======================")
// 
disp("A standard linear regression looks like this.")

X = rand(30,1,"n");
Y = 2+3*X+rand(30,1,"n");
clf();
linreg(Y,X);
ax=gca();ax.grid=[1 1];

halt()

// Strike any key to continue.
disp("You may identify observations here too.")
disp("Click with the mouse. End with middle button.")
 
identify(X,Y,1)

disp("==========================================================")
disp("DATA MATERIALS")
//
disp("There are some data materials included.")
disp("==========================================================")

 
x = getdata();
if size(x,2) < 2 
	clf();
	plot2d((1:size(x,"*"))',x(:,1),style=-9); 
else
	plot2d(x(:,1),x(:,2),style=-9); 
end 
halt()

clf();

m = 12;
x = [rand(m,1,"n");rand(m,1,"n")+2;rand(m,1,"n")+4];
y = [rand(m,1,"n");rand(m,1,"n")+4;rand(m,1,"n")+3];
s = ones(m,1)*[1,2,3];
s = s(:);
plotsym(x,y,s,"stc","k");

halt()


disp("================= FANCY PLOTTING ====================")
// 
disp("2. Plot with different colors")
 
z = (1:3*m)';
 
plotsym(x,y,s,"stc",z);
 
xset("colormap",hotcolormap(32));
 
halt()

disp("================= FANCY PLOTTING ====================")
// 
disp("3. Plot with different sizes instead")
 
z = z/max(z)*5;
 
plotsym(x,y,s,"stc","k",z);
 
halt()

disp("================= FANCY PLOTTING ====================")
// 
disp("4. Random place, form, color, and size. A really cool plot ...")
 
m = 100;
x = rand(m,1,"n");
y = rand(m,1,"n");
form = ceil(rand(m,1,"u")*7);
// note: 7 forms available
mycolor = ceil(32*rand(m,1,"u"));
ssize = rand(m,1,"u")*4+1;
 
plotsym(x,y,form,mycolor,ssize);
halt() 
%v=(0:31)'/31;
xset("colormap",[%v,1-%v,ones(%v)]);
plotsym(x,y,form,mycolor,ssize);
 
halt()

disp('================= BYE ====================');
// 
disp('Thanks for your attention. Good bye.');

//
// Load this script into the editor
//
filename = "stixdemo.dem.sce";
dname = get_absolute_file_path(filename);
editor ( fullfile(dname,filename) );

